Module ref_format

Module ref_format 

Shared validation for git reference names.

Branches and tags are both git refs and share the rules enforced by git check-ref-format. This module is the single source of truth for those rules; type-specific newtypes (Branch, Tag) delegate to validate.

Enums

RefFormatError
Errors that can occur when validating a git reference name.

Functions

validate
Validate a git reference name against git check-ref-format rules.