Module reset

Module reset 

git reset command builder.

Uses the same typestate as checkout for the optional commit-ish target, but Build/status are available in both states because git reset without a target is valid (defaults to HEAD).

Structs

Reset
Builder for git reset command.

Functions

new
Create a new git reset command builder.