git reset command builder.
Uses the same typestate as checkout for the optional commit-ish target,
but Build/status are available in both states because git reset
without a target is valid (defaults to HEAD).
Structs
- Reset
- Builder for
git resetcommand.
Functions
- new
- Create a new
git resetcommand builder.